@@ -1,12 +1,10 @@
 '''Tests the taskqueue local backend.'''
 from random import random
 from time import time
-from datetime import datetime, timedelta
 
 from pulsar import send, get_application, multi_async
 from pulsar.apps import tasks, rpc
-from pulsar.utils.timeutils import timedelta_seconds
-from pulsar.apps.test import unittest, run_on_arbiter, dont_run_with_thread
+from pulsar.apps.test import unittest, dont_run_with_thread
 
 from .manage import server
 
@@ -17,7 +15,7 @@ def task_function(N = 10, lag = 0.1):
     time.sleep(lag)
     return N*N
 '''
-            
+
 
 class TaskQueueBase(object):
     concurrency = 'thread'
@@ -27,19 +25,19 @@ class TaskQueueBase(object):
     rpc_timeout = 500
     concurrent_tasks = 6
     apps = ()
-    
+
     @classmethod
     def name(cls):
         return cls.__name__.lower()
-    
+
     @classmethod
     def task_backend(cls):
         return None
-    
+
     @classmethod
     def rpc_name(cls):
         return 'rpc_%s' % cls.name()
-    
+
     @classmethod
     def setUpClass(cls):
         # The name of the task queue application
@@ -64,35 +62,14 @@ class TaskQueueBase(object):
     def tearDownClass(cls):
         cmnds = [send('arbiter', 'kill_actor', a.name) for a in cls.apps]
         yield multi_async(cmnds)
-        
+
     def pubsub_test(self, app):
         pubsub = app.backend.pubsub
         self.assertEqual(pubsub.backend.connection_string,
                          'local://?name=%s' % app.name)
-        
-        
+
+
 class TestTaskQueueOnThread(TaskQueueBase, unittest.TestCase):
-        
-    def test_run_producerconsumer(self):
-        '''A task which produce other tasks'''
-        sample = 5
-        r = yield self.proxy.run_new_task(jobname='standarddeviation',
-                                          sample=sample, size=100)
-        self.assertTrue(r)
-        r = yield self.proxy.wait_for_task(r)
-        self.assertEqual(r['status'], tasks.SUCCESS)
-        self.assertEqual(r['result'], 'produced %s new tasks' % sample)
-        self.assertTrue(tasks.nice_task_message(r))
-        # We check for the tasks created
-        created = yield self.proxy.get_tasks(from_task=r['id'])
-        self.assertEqual(len(created), sample)
-        stasks = []
-        for task in created:
-            stasks.append(self.proxy.wait_for_task(task['id']))
-        created = yield multi_async(stasks)
-        self.assertEqual(len(created), sample)
-        for task in created:
-            self.assertEqual(task['status'], tasks.SUCCESS)
 
     def test_pickled_app(self):
         tq = self.apps[0]
@@ -102,7 +79,7 @@ class TestTaskQueueOnThread(TaskQueueBase, unittest.TestCase):
         self.assertEqual(backend.poll_timeout, 2)
         self.assertEqual(backend.num_concurrent_tasks, 0)
         self.assertEqual(backend.backlog, self.concurrent_tasks)
-    
+
     def test_meta(self):
         '''Tests meta attributes of taskqueue'''
         app = yield get_application(self.name())
@@ -118,10 +95,10 @@ class TestTaskQueueOnThread(TaskQueueBase, unittest.TestCase):
         job = app.backend.registry['runpycode']
         self.assertEqual(job.type, 'regular')
         self.assertTrue(job.can_overlap)
-        id, oid = job.generate_task_ids((),{})
+        id, oid = job.generate_task_ids((), {})
         self.assertTrue(id)
         self.assertFalse(oid)
-        id1, oid = job.generate_task_ids((),{})
+        id1, oid = job.generate_task_ids((), {})
         self.assertNotEqual(id, id1)
         self.assertFalse(oid)
 
@@ -145,12 +122,12 @@ class TestTaskQueueOnThread(TaskQueueBase, unittest.TestCase):
         self.assertEqual(app.cfg.concurrency, self.concurrency)
         wsgi_handler = app.callable.handler
         self.assertEqual(len(wsgi_handler.middleware), 1)
-        router = wsgi_handler.middleware[0] 
+        router = wsgi_handler.middleware[0]
         self.assertTrue(router.post)
         root = router.post
         tq = root.taskqueue
         self.assertEqual(tq, self.name())
-        
+
     def test_registry(self):
         app = yield get_application(self.name())
         self.assertTrue(isinstance(app.backend.registry, dict))
@@ -175,7 +152,7 @@ class TestTaskQueueOnThread(TaskQueueBase, unittest.TestCase):
         result = r['result']
         self.assertTrue(result['loops'])
         self.assertTrue(result['time'] > 3)
-      
+
     def test_run_new_task_asynchronous_wait_on_test(self):
         app = yield get_application(self.name())
         r = yield self.proxy.run_new_task(jobname='asynchronous', lag=3)
@@ -183,20 +160,20 @@ class TestTaskQueueOnThread(TaskQueueBase, unittest.TestCase):
         self.assertEqual(r.status, tasks.SUCCESS)
         self.assertTrue(r.result['loops'])
         self.assertTrue(r.result['time'] > 3)
-        
+
     def test_run_new_simple_task_from_test(self):
         app = yield get_application(self.name())
         r = yield app.backend.run('addition', a=1, b=2)
         r = yield self.proxy.wait_for_task(r)
         self.assertEqual(r['status'], tasks.SUCCESS)
         self.assertEqual(r['result'], 3)
-    
+
     def test_run_new_simple_task(self):
         r = yield self.proxy.run_new_task(jobname='addition', a=40, b=50)
         r = yield self.proxy.wait_for_task(r)
         self.assertEqual(r['status'], tasks.SUCCESS)
         self.assertEqual(r['result'], 90)
-    
+
     def test_not_overlap(self):
         sec = 2 + random()
         app = yield get_application(self.name())
@@ -232,15 +209,16 @@ class TestTaskQueueOnThread(TaskQueueBase, unittest.TestCase):
         r = yield self.proxy.wait_for_task(r)
         self.assertEqual(r['status'], tasks.FAILURE)
         self.assertTrue('kaputt' in r['result'])
-     
+
     def test_run_new_task_expiry(self):
         r = yield self.proxy.run_new_task(jobname='addition', a=40, b=50,
                                           meta_data={'expiry': time()})
         self.assertTrue(r)
         r = yield self.proxy.wait_for_task(r)
         self.assertEqual(r['status'], tasks.REVOKED)
-           
-    def test_delete_task(self):
+
+    def __test_delete_task(self):
+        #ISSUE #56
         app = yield get_application(self.name())
         id = yield app.backend.run('addition', 1, 4)
         r1 = yield app.backend.wait_for_task(id)
@@ -249,7 +227,7 @@ class TestTaskQueueOnThread(TaskQueueBase, unittest.TestCase):
         self.assertEqual(len(deleted), 1)
         r1 = yield app.backend.get_task(r1.id)
         self.assertFalse(r1)
-      
+
     def test_run_producerconsumer(self):
         '''A task which produce other tasks'''
         sample = 5
@@ -272,21 +250,12 @@ class TestTaskQueueOnThread(TaskQueueBase, unittest.TestCase):
             self.assertEqual(task['status'], tasks.SUCCESS)
 
     ##    RPC TESTS
-    def test_rpc_job_list(self):
-        jobs = yield self.proxy.job_list()
-        self.assertTrue(jobs)
-        self.assertTrue(isinstance(jobs, list))
-        d = dict(jobs)
-        pycode = d['runpycode']
-        self.assertEqual(pycode['type'], 'regular')
-
     def test_check_next_run(self):
         app = yield get_application(self.name())
         backend = app.backend
-        now = datetime.now()
         backend.tick()
         #self.assertTrue(backend.next_run > now)
-        
+
     def test_rpc_ping(self):
         yield self.async.assertEqual(self.proxy.ping(), 'pong')
 
@@ -297,13 +266,13 @@ class TestTaskQueueOnThread(TaskQueueBase, unittest.TestCase):
         d = dict(jobs)
         pycode = d['runpycode']
         self.assertEqual(pycode['type'], 'regular')
-      
+
     def test_rpc_job_list_with_names(self):
         jobs = yield self.proxy.job_list(jobnames=['runpycode'])
         self.assertEqual(len(jobs), 1)
         jobs = yield self.proxy.job_list(jobnames=['xxxxxx'])
         self.assertEqual(len(jobs), 0)
-       
+
     def test_rpc_next_scheduled_tasks(self):
         next = yield self.proxy.next_scheduled_tasks()
         self.assertTrue(next)
@@ -313,34 +282,35 @@ class TestTaskQueueOnThread(TaskQueueBase, unittest.TestCase):
         self.assertEqual(len(next), 2)
         self.assertEqual(next[0], 'testperiodic')
         self.assertTrue(next[1] >= 0)
-        
+
     def test_id_not_overlap(self):
-        '''Check `generate_task_ids` when `can_overlap` attribute is set to False.'''
+        '''Check `generate_task_ids` when `can_overlap` attribute is set to
+        False.'''
         app = yield get_application(self.name())
         job = app.backend.registry['notoverlap']
         self.assertEqual(job.type, 'regular')
         self.assertFalse(job.can_overlap)
         #
-        id1, oid1 = job.generate_task_ids((),{})
+        id1, oid1 = job.generate_task_ids((), {})
         self.assertTrue(oid1)
-        id2, oid2 = job.generate_task_ids((),{})
+        id2, oid2 = job.generate_task_ids((), {})
         self.assertTrue(oid2)
         self.assertNotEqual(id2, id1)
         self.assertEqual(oid2, oid1)
         #
-        id3, oid3 = job.generate_task_ids((10,'bla'),{'p':45})
+        id3, oid3 = job.generate_task_ids((10, 'bla'), {'p': 45})
         self.assertTrue(oid3)
         self.assertNotEqual(id3, id2)
         self.assertNotEqual(oid3, oid2)
-        id4, oid4 = job.generate_task_ids((10,'bla'),{'p':45})
+        id4, oid4 = job.generate_task_ids((10, 'bla'), {'p': 45})
         self.assertNotEqual(id4, id3)
         self.assertEqual(oid4, oid3)
         #
-        id5, oid5 = job.generate_task_ids((),{'p':45,'c':'bla'})
+        id5, oid5 = job.generate_task_ids((), {'p': 45, 'c': 'bla'})
         self.assertTrue(oid5)
-        id6, oid6 = job.generate_task_ids((),{'p':45,'c':'bla'})
-        id7, oid7 = job.generate_task_ids((),{'p':45,'d':'bla'})
-        id8, oid8 = job.generate_task_ids((),{'p':45,'c':'blas'})
+        id6, oid6 = job.generate_task_ids((), {'p': 45, 'c': 'bla'})
+        id7, oid7 = job.generate_task_ids((), {'p': 45, 'd': 'bla'})
+        id8, oid8 = job.generate_task_ids((), {'p': 45, 'c': 'blas'})
         #
         self.assertEqual(oid5, oid6)
         self.assertNotEqual(oid5, oid7)
