@@ -3,167 +3,185 @@ from time import time
 
 from pulsar import HaltServer, CommandError, system
 from pulsar.utils.pep import pickle
-from pulsar.utils.log import LogginMixin
+from pulsar.utils.log import LogginMixin, WritelnDecorator
 
 from .eventloop import setid
-from .defer import async, EventHandler, Failure
+from .defer import Failure
+from .events import EventHandler
 from .threads import ThreadPool
 from .proxy import ActorProxy, ActorProxyMonitor, ActorIdentity
 from .mailbox import command_in_context
 from .access import get_actor
+from .cov import Coverage
 from .consts import *
 
 
-__all__ = ['is_actor', 'send', 'Actor', 'ACTOR_STATES', 'Pulsar']
+__all__ = ['is_actor', 'send', 'Actor', 'ACTOR_STATES', 'Pulsar', 'get_stream']
 
 
 def is_actor(obj):
     return isinstance(obj, Actor)
 
+
+def get_stream(cfg):
+    '''Obtain the python stream handler given a config dictionary.
+    '''
+    stream = sys.stderr
+    return WritelnDecorator(stream)
+
+
 def send(target, action, *args, **params):
-    '''Send a :ref:`message <api-remote_commands>` to ``target`` to perform
-a given ``action``. The actor sending the message is obtained via the
-:func:`get_actor` function.
+    '''Send a :ref:`message <api-remote_commands>` to ``target``
 
-:parameter target: the :class:`Actor` id or an :class:`ActorProxy` or name of
-    the target actor which will receive the message.
-:parameter action: the name of the :ref:`remote command <api-remote_commands>`
-    to perform in the *target* :class:`Actor`.
-:parameter args: positional arguments to pass to the
-    :ref:`remote command <api-remote_commands>` *action*.
-:parameter params: dictionary of parameters to pass to
-    :ref:`remote command <api-remote_commands>` *action*.
-:rtype: a :class:`Deferred` if the action acknowledge the caller or `None`.
+    The message is to perform a given ``action``. The actor sending the
+    message is obtained via the :func:`get_actor` function.
 
-Typical example::
+    :parameter target: the :class:`Actor` id or an :class:`ActorProxy` or
+        name of the target actor which will receive the message.
+    :parameter action: the :ref:`remote command <api-remote_commands>`
+        to perform in the ``target`` :class:`Actor`.
+    :parameter args: positional arguments to pass to the
+        :ref:`remote command <api-remote_commands>` ``action``.
+    :parameter params: dictionary of parameters to pass to
+        :ref:`remote command <api-remote_commands>` ``action``.
+    :return: a :class:`Deferred` if the action acknowledge the caller or
+        `None`.
 
-    >>> a = spawn()
-    >>> r = a.add_callback(lambda p: send(p,'ping'))
-    >>> r.result
-    'pong'
-'''
+    Typical example::
+
+        >>> a = spawn()
+        >>> r = a.add_callback(lambda p: send(p,'ping'))
+        >>> r.result
+        'pong'
+    '''
     return get_actor().send(target, action, *args, **params)
 
 
 class Pulsar(LogginMixin):
-    
+
     def configure_logging(self, **kwargs):
         configure_logging = super(Pulsar, self).configure_logging
         configure_logging(logger='pulsar',
                           config=self.cfg.logconfig,
                           level=self.cfg.loglevel,
-                          handlers=self.cfg.loghandlers) 
+                          handlers=self.cfg.loghandlers)
         configure_logging(logger='pulsar.%s' % self.name,
                           config=self.cfg.logconfig,
                           level=self.cfg.loglevel,
                           handlers=self.cfg.loghandlers)
-        
 
-class Actor(EventHandler, Pulsar, ActorIdentity):
-    '''The base class for parallel execution in pulsar. In computer science,
-the **Actor model** is a mathematical model of concurrent computation that
-treats *actors* as the universal primitives of computation.
-In response to a message that it receives, an actor can make local decisions,
-create more actors, send more messages, and determine how to respond to
-the next message received.
 
-The current implementation allows for actors to perform specific tasks such
-as listening to a socket, acting as http server, consuming
-a task queue and so forth.
+class Actor(EventHandler, Pulsar, ActorIdentity, Coverage):
+    '''The base class for parallel execution in pulsar.
 
-To spawn a new actor::
+    In computer science, the **Actor model** is a mathematical model
+    of concurrent computation that treats *actors* as the universal primitives
+    of computation.
+    In response to a message that it receives, an actor can make local
+    decisions, create more actors, send more messages, and determine how
+    to respond to the next message received.
 
-    >>> from pulsar import spawn
-    >>> a = spawn()
-    >>> a.is_alive()
-    True
+    The current implementation allows for actors to perform specific tasks
+    such as listening to a socket, acting as http server, consuming
+    a task queue and so forth.
 
-Here ``a`` is actually a reference to the remote actor, it is
-an :class:`ActorProxy`.
+    To spawn a new actor::
 
-**ATTRIBUTES**
+        >>> from pulsar import spawn
+        >>> a = spawn()
+        >>> a.is_alive()
+        True
 
-.. attribute:: name
+    Here ``a`` is actually a reference to the remote actor, it is
+    an :class:`ActorProxy`.
 
-    The name of this :class:`Actor`.
-    
-.. attribute:: aid
+    **ATTRIBUTES**
 
-    Unique ID for this :class:`Actor`.
-    
-.. attribute:: impl
+    .. attribute:: name
 
-    The :class:`Concurrency` implementation for this :class:`Actor`.
-    
-.. attribute:: event_loop
+        The name of this :class:`Actor`.
 
-    An instance of :class:`EventLoop` which listen for input/output events
-    on sockets or socket-like :class:`Transport`. It is the driver of the
-    :class:`Actor`. If the :attr:event_loop` stps, the :class:`Actor` stop
-    running and goes out of scope.
+    .. attribute:: aid
 
-.. attribute:: mailbox
+        Unique ID for this :class:`Actor`.
 
-    Used to send and receive :ref:`actor messages <tutorials-messages>`.
-    
-.. attribute:: address
+    .. attribute:: impl
 
-    The socket address for this :attr:`Actor.mailbox`.
-    
-.. attribute:: proxy
+        The :class:`Concurrency` implementation for this :class:`Actor`.
 
-    Instance of a :class:`ActorProxy` holding a reference
-    to this :class:`Actor`. The proxy is a lightweight representation
-    of the actor which can be shared across different processes
-    (i.e. it is picklable).
+    .. attribute:: event_loop
 
-.. attribute:: state
+        An instance of :class:`EventLoop` which listen for input/output events
+        on sockets or socket-like :class:`Transport`. It is the driver of the
+        :class:`Actor`. If the :attr:event_loop` stps, the :class:`Actor` stop
+        running and goes out of scope.
 
-    The actor :ref:`numeric state <actor-states>`.
-    
-.. attribute:: thread_pool
+    .. attribute:: mailbox
 
-    A :class:`ThreadPool` associated with this :class:`Actor`. This attribute
-    is ``None`` unless one is created via the :meth:`create_thread_pool`
-    method.
+        Used to send and receive :ref:`actor messages <tutorials-messages>`.
 
-.. attribute:: params
+    .. attribute:: address
 
-    A :class:`pulsar.utils.structures.AttributeDictionary` which contains
-    parameters which are passed to actors spawned by this actor.
-    
-.. attribute:: extra
+        The socket address for this :attr:`Actor.mailbox`.
 
-    A dictionary which can be populated with extra parameters useful
-    for other actors. This dictionary is included in the dictionary
-    returned by the :meth:`info` method.
-    Check the :ref:`info command <actor_info_command>` for how to obtain
-    information about an actor.
-    
-.. attribute:: info_state
+    .. attribute:: proxy
 
-    Current state description string. One of ``initial``, ``running``,
-    ``stopping``, ``closed`` and ``terminated``.
-    
-.. attribute:: next_periodic_task
+        Instance of a :class:`ActorProxy` holding a reference
+        to this :class:`Actor`. The proxy is a lightweight representation
+        of the actor which can be shared across different processes
+        (i.e. it is picklable).
 
-    The :class:`TimedCall` for the next
-    :ref:`actor periodic task <actor-periodic-task>`.
- 
-**PUBLIC METHODS**
-'''
+    .. attribute:: state
+
+        The actor :ref:`numeric state <actor-states>`.
+
+    .. attribute:: thread_pool
+
+        A :class:`ThreadPool` associated with this :class:`Actor`.
+        This attribute is ``None`` unless one is created via the
+        :meth:`create_thread_pool` method.
+
+    .. attribute:: params
+
+        A :class:`pulsar.utils.structures.AttributeDictionary` which contains
+        parameters which are passed to actors spawned by this actor.
+
+    .. attribute:: extra
+
+        A dictionary which can be populated with extra parameters useful
+        for other actors. This dictionary is included in the dictionary
+        returned by the :meth:`info` method.
+        Check the :ref:`info command <actor_info_command>` for how to obtain
+        information about an actor.
+
+    .. attribute:: info_state
+
+        Current state description string. One of ``initial``, ``running``,
+        ``stopping``, ``closed`` and ``terminated``.
+
+    .. attribute:: next_periodic_task
+
+        The :class:`TimedCall` for the next
+        :ref:`actor periodic task <actor-periodic-task>`.
+
+    .. attribute:: stream
+
+        A ``stream`` handler to write information messages without using
+        the :attr:`logger`.
+    '''
     ONE_TIME_EVENTS = ('start', 'stopping', 'stop')
+    MANY_TIMES_EVENTS = ('on_info', 'on_params')
     exit_code = None
     mailbox = None
     signal_queue = None
     next_periodic_task = None
-    
+
     def __init__(self, impl):
         super(Actor, self).__init__()
         self.state = ACTOR_STATES.INITIAL
         self._thread_pool = None
         self.__impl = impl
-        for name in self.all_events():
+        for name in self.events:
             hook = impl.params.pop(name, None)
             if hook:
                 self.bind_event(name, hook)
@@ -171,6 +189,7 @@ an :class:`ActorProxy`.
         self.params = AttributeDictionary(**impl.params)
         self.servers = {}
         self.extra = {}
+        self.stream = get_stream(self.cfg)
         del impl.params
         setid(self)
         try:
@@ -180,10 +199,10 @@ an :class:`ActorProxy`.
 
     def __repr__(self):
         return self.impl.unique_name
-    
+
     def __str__(self):
         return self.__repr__()
-    
+
     ############################################################### PROPERTIES
     @property
     def name(self):
@@ -192,15 +211,15 @@ an :class:`ActorProxy`.
     @property
     def aid(self):
         return self.__impl.aid
-    
+
     @property
     def impl(self):
         return self.__impl
-    
+
     @property
     def cfg(self):
         return self.__impl.cfg
-    
+
     @property
     def proxy(self):
         return ActorProxy(self)
@@ -212,7 +231,7 @@ an :class:`ActorProxy`.
     @property
     def event_loop(self):
         return self.mailbox.event_loop
-    
+
     @property
     def thread_pool(self):
         return self._thread_pool
@@ -221,69 +240,54 @@ an :class:`ActorProxy`.
     def info_state(self):
         return ACTOR_STATES.DESCRIPTION[self.state]
 
-    ############################################################################
+    #######################################################################
     ##    HIGH LEVEL API METHODS
-    ############################################################################
+    #######################################################################
     def start(self):
-        '''Called after forking to start the actor's life. This is where
-logging is configured, the :attr:`Actor.mailbox` is registered and the
-:attr:`Actor.event_loop` is initialised and started. Calling this method
-more than once does nothing.'''
+        '''Called after forking to start the actor's life.
+
+        This is where logging is configured, the :attr:`Actor.mailbox` is
+        registered and the :attr:`Actor.event_loop` is initialised and
+        started. Calling this method more than once does nothing.
+        '''
         if self.state == ACTOR_STATES.INITIAL:
             self.__impl.before_start(self)
-            self._started = time() 
+            self._started = time()
             self.configure_logging()
             self.__impl.setup_event_loop(self)
             self.state = ACTOR_STATES.STARTING
             self._run()
 
-    @async()
-    def send(self, target, action, *args, **kwargs):
+    def send(self, target, action, *args, **kw):
         '''Send a message to ``target`` to perform ``action`` with given
 positional ``args`` and key-valued ``kwargs``.
 Always return a :class:`Deferred`.'''
-        target = self.monitor if target == 'monitor' else target
-        mailbox = self.mailbox
-        if isinstance(target, ActorProxyMonitor):
-            mailbox = target.mailbox
-        else:
-            actor = self.get_actor(target)
-            if isinstance(actor, Actor):
-                # this occur when sending a message from arbiter to monitors or
-                # viceversa.
-                return command_in_context(action, self, actor, args, kwargs)
-            elif isinstance(actor, ActorProxyMonitor):
-                mailbox = actor.mailbox
-        if hasattr(mailbox, 'request'):
-            #if not mailbox.closed:
-            return mailbox.request(action, self, target, args, kwargs)
-        else:
-            raise CommandError('Cannot execute "%s" in %s. Unknown actor %s.'
-                               % (action, self, target))
-    
+        return self.event_loop.async(self._send(target, action, *args, **kw))
+
     def spawn(self, **params):
         raise RuntimeError('Cannot spawn an actor from an actor.')
-    
+
     def stop(self, exc=None):
         '''Gracefully stop the :class:`Actor`.
-        
+
         Implemented by the :meth:`Concurrency.stop` method of the :attr:`impl`
         attribute.'''
         return self.__impl.stop(self, exc)
-    
+
     def create_thread_pool(self, workers=None):
         '''Create a :class:`ThreadPool` for this :class:`Actor`
-if not already present.
+        if not already present.
 
-:param workers: number of threads to use in the :class:`ThreadPool`. If not
-    supplied, the value in the :ref:`setting-thread_workers` setting is used.
-:return: a :class:`ThreadPool`.
-'''
+        :param workers: number of threads to use in the :class:`ThreadPool`.
+            If not supplied, the value in the :ref:`setting-thread_workers`
+            setting is used.
+        :return: a :class:`ThreadPool`.
+        '''
         if self._thread_pool is None:
             workers = workers or self.cfg.thread_workers
             self._thread_pool = ThreadPool(self, threads=workers)
         return self._thread_pool
-    
+
     def close_thread_pool(self):
         '''Close the :attr:`thread_pool`.'''
         if self._thread_pool:
@@ -294,14 +298,14 @@ if not already present.
             self._thread_pool.join()
             self.logger.debug('Thread pool %s' % self._thread_pool.status)
             self._thread_pool = None
-            
+
     ###############################################################  STATES
     def is_running(self):
         '''``True`` if actor is running, that is when the :attr:`state`
 is equal to :ref:`ACTOR_STATES.RUN <actor-states>` and the event loop is
 running.'''
         return self.state == ACTOR_STATES.RUN and self.event_loop.is_running()
-    
+
     def started(self):
         '''``True`` if actor has started. It does not necessarily
 mean it is running. Its state is greater or equal
@@ -309,13 +313,18 @@ mean it is running. Its state is greater or equal
         return self.state >= ACTOR_STATES.RUN
 
     def closed(self):
-        '''``True`` if actor has exited in an clean fashion. It :attr:`state`
-is equal to :ref:`ACTOR_STATES.CLOSE <actor-states>`.'''
+        '''``True`` if actor has exited in an clean fashion.
+
+        Its :attr:`state` is :ref:`ACTOR_STATES.CLOSE <actor-states>`.
+        '''
         return self.state == ACTOR_STATES.CLOSE
 
     def stopped(self):
-        '''``True`` if actor has exited so that it :attr:`state` is greater
-or equal to :ref:`ACTOR_STATES.CLOSE <actor-states>`.'''
+        '''``True`` if actor has exited.
+
+        Its :attr:`state` is greater or equal to
+        :ref:`ACTOR_STATES.CLOSE <actor-states>`.
+        '''
         return self.state >= ACTOR_STATES.CLOSE
 
     def is_arbiter(self):
@@ -331,12 +340,12 @@ or equal to :ref:`ACTOR_STATES.CLOSE <actor-states>`.'''
         return self.__impl.is_process()
 
     def __reduce__(self):
-        raise pickle.PicklingError('{0} - Cannot pickle Actor instances'\
+        raise pickle.PicklingError('{0} - Cannot pickle Actor instances'
                                    .format(self))
-    
-    ############################################################################
+
+    #######################################################################
     #    INTERNALS
-    ############################################################################   
+    #######################################################################
     def get_actor(self, aid):
         '''Given an actor unique id return the actor proxy.'''
         if aid == self.aid:
@@ -350,12 +359,14 @@ status and performance. The dictionary contains the following entries:
 
 * ``actor`` a dictionary containing information regarding the type of actor
   and its status.
-* ``events`` a dictionary of information about the event loop running the actor.
+* ``events`` a dictionary of information about the event loop running the
+  actor.
 * ``extra`` the :attr:`extra` attribute (which you can use to add stuff).
 * ``system`` system info.
 
-This method is invoked when you run the :ref:`info command <actor_info_command>`
-from another actor.'''
+This method is invoked when you run the
+:ref:`info command <actor_info_command>` from another actor.
+'''
         if not self.started():
             return
         isp = self.is_process()
@@ -374,15 +385,16 @@ from another actor.'''
                 'extra': self.extra}
         if isp:
             data['system'] = system.system_info(self.pid)
+        self.fire_event('on_info', info=data)
         return data
-    
+
     def _run(self, initial=True):
         exc = None
         if initial:
             try:
                 self.cfg.when_ready(self)
-            except Exception:
-                pass
+            except Exception:   # pragma    nocover
+                self.logger.exception('Unhandled exception in when_ready hook')
         try:
             exc = self.__impl.run_actor(self)
         except (Exception, HaltServer):
@@ -394,5 +406,23 @@ from another actor.'''
         finally:
             if exc != -1:
                 self.stop(exc)
-            
-        
\ No newline at end of file
+
+    def _send(self, target, action, *args, **kwargs):
+        target = self.monitor if target == 'monitor' else target
+        mailbox = self.mailbox
+        if isinstance(target, ActorProxyMonitor):
+            mailbox = target.mailbox
+        else:
+            actor = self.get_actor(target)
+            if isinstance(actor, Actor):
+                # this occur when sending a message from arbiter to monitors or
+                # viceversa.
+                return command_in_context(action, self, actor, args, kwargs)
+            elif isinstance(actor, ActorProxyMonitor):
+                mailbox = actor.mailbox
+        if hasattr(mailbox, 'request'):
+            #if not mailbox.closed:
+            return mailbox.request(action, self, target, args, kwargs)
+        else:
+            raise CommandError('Cannot execute "%s" in %s. Unknown actor %s.'
+                               % (action, self, target))
