@@ -16,12 +16,12 @@ from pulsar.utils.pep import (default_timer, set_event_loop_policy,
                               set_event_loop, range,
                               EventLoop as BaseEventLoop,
                               EventLoopPolicy as BaseEventLoopPolicy)
-from pulsar.utils.internet import SOCKET_INTERRUPT_ERRORS
 from pulsar.utils.exceptions import StopEventLoop, ImproperlyConfigured
 
 from .access import thread_local_data, LOGGER
 from .defer import Task, Deferred, Failure, TimeoutError
-from .stream import create_connection, start_serving, sock_connect, sock_accept
+from .stream import (create_connection, start_serving, sock_connect,
+                     sock_accept, raise_socket_error)
 from .udp import create_datagram_endpoint
 from .consts import DEFAULT_CONNECT_TIMEOUT, DEFAULT_ACCEPT_TIMEOUT
 from .pollers import DefaultIO
@@ -678,6 +678,8 @@ the event loop to poll with a 0 timeout all the times.'''
             try:
                 value = callback()
             except socket.error as e:
+                if raise_socket_error(e) and self.running:
+                    exc_info = sys.exc_info()
                 if self._raise_loop_error(e):
                     exc_info = sys.exc_info()
             except Exception:
@@ -695,24 +697,13 @@ the event loop to poll with a 0 timeout all the times.'''
         try:
             event_pairs = io.poll(timeout)
         except Exception as e:
-            if self._raise_loop_error(e):
+            if raise_socket_error(e) and self.running:
                 raise
         except KeyboardInterrupt:
             raise StopEventLoop
         else:
             for fd, events in event_pairs:
-                callbacks.append(partial(io.handle_events, self, fd, events))
-
-    def _raise_loop_error(self, e):
-        # Depending on python version and EventLoop implementation,
-        # different exception types may be thrown and there are
-        # two ways EINTR might be signaled:
-        # * e.errno == errno.EINTR
-        # * e.args is like (errno.EINTR, 'Interrupted system call')
-        eno = getattr(e, 'errno', None)
-        if eno not in SOCKET_INTERRUPT_ERRORS:
-            args = getattr(e, 'args', None)
-            if isinstance(args, tuple) and len(args) == 2:
-                eno = args[0]
-        if eno not in SOCKET_INTERRUPT_ERRORS and self.running:
-            return True
+                try:
+                    io.handle_events(self, fd, events)
+                except KeyError:
+                    pass
