@@ -389,7 +389,8 @@ SERVER_HEADER_FIELDS = HEADER_FIELDS['general'].union(
     HEADER_FIELDS['entity'], HEADER_FIELDS['response'])
 ALL_HEADER_FIELDS = CLIENT_HEADER_FIELDS.union(SERVER_HEADER_FIELDS)
 ALL_HEADER_FIELDS_DICT = dict(((k.lower(), k) for k in ALL_HEADER_FIELDS))
-
+HEADER_FIELDS_JOINER = {'Set-Cookie': None,
+                        'Set-Cookie2': None}
 TYPE_HEADER_FIELDS = {'client': CLIENT_HEADER_FIELDS,
                       'server': SERVER_HEADER_FIELDS,
                       'both': ALL_HEADER_FIELDS}
@@ -599,7 +600,7 @@ header fields.
         key = header_field(key, self.all_headers, self.strict)
         if key and value is not None:
             if not isinstance(value, list):
-                value = self.get_values(value)
+                value = [value]
             self._headers[key] = value
 
     def get(self, key, default=None):
@@ -669,14 +670,11 @@ results in::
         key = header_field(key, self.all_headers, self.strict)
         if key and value:
             values = self._headers.get(key, [])
-            lower_values = [v.lower() for v in values]
-            for value in self.get_values(value):
-                if params:
-                    value = '%s; %s' % (value, '; '.join(('%s=%s' % kv for kv
-                                                          in params.items())))
-                lower_value = value.lower()
-                if lower_value not in lower_values:
-                    lower_values.append(lower_value)
+            value = value.strip()
+            if params:
+                value = '%s; %s' % (value, '; '.join(('%s=%s' % kv for kv
+                                                      in params.items())))
+            if value not in values:
                     values.append(value)
             self._headers[key] = values
 
@@ -707,6 +705,8 @@ results in::
 
     def _ordered(self):
         hf = HEADER_FIELDS
+        hj = HEADER_FIELDS_JOINER
+        dj = ', '
         order = (('general', []), ('request', []),
                  ('response', []), ('entity', []))
         headers = self._headers
@@ -719,14 +719,15 @@ results in::
                 group.append(key)
         for _, group in order:
             for k in group:
-                yield "%s: %s" % (k, ', '.join(headers[k]))
+                joiner = hj.get(k, dj)
+                if not joiner:
+                    for header in headers[k]:
+                        yield "%s: %s" % (k, header)
+                else:
+                    yield "%s: %s" % (k, joiner.join(headers[k]))
         yield ''
         yield ''
 
-    ##    INTERNALS
-    def get_values(self, value):
-        return [v for v in (v.strip() for v in value.split(',')) if v]
-
 
 ###############################################################################
 ##    HTTP PARSER
